@@ -21,6 +21,7 @@ from laipvt.controller.service.license import LicenseController
 from laipvt.controller.service.mage import MageController
 from laipvt.controller.service.ocr_standard import OcrStandardController
 from laipvt.controller.service.nlp import NlpController
+from laipvt.controller.service.seal import SealController
 from laipvt.controller.service.captcha import CaptchaController
 from laipvt.controller.service.commander import CommanderController
 from laipvt.controller.service.ocr import OcrController
@@ -30,9 +31,9 @@ from laipvt.handler.middlewarehandler import EtcdConfigHandler, MysqlConfigHandl
     MinioConfigHandler, RabbitmqConfigHandler, RedisConfigHandler, HarborConfigHandler, NginxConfigHandler, \
     IdentityConfigHandler, SiberConfigHandler, OcrConfigHandler, MonitorConfigHandler, KeepalivedConfigHandler
 from laipvt.sysutil.relation import module_require_tfserver, tfserver_name, tfserver_image_name
-from laipvt.sysutil.util import write_to_file, read_form_json_file
+from laipvt.sysutil.util import write_to_file, read_form_json_file, gen_https_self_signed_ca
 from laipvt.sysutil.kube_common import wait_pod_running
-from laipvt.sysutil.check import is_pre_check
+from laipvt.sysutil.check import is_pre_check, check_use_https_ca, check_https_ca_self_signed
 
 def deploy_main(args):
     if not args.isCheck:
@@ -40,6 +41,13 @@ def deploy_main(args):
             print("ERROR: 未执行前置检查或前置检查失败")
             exit(1)
 
+    if not check_use_https_ca():
+        print("Error: 使用https部署，选择的是客户提供证书，证书路径不正确")
+        exit(1)
+
+    if check_https_ca_self_signed():
+        gen_https_self_signed_ca()
+
     # 获取前置检查结果
     check_result_file = CHECK_FILE
     check_result = CheckResultHandler(check_result_file)
@@ -99,16 +107,17 @@ def deploy_main(args):
         kube.add_hosts()
         kube.system_prepare()
         kube.init_primary_master()
+        kube.cp_kube_config()
         kube.kube_completion()
         kube.install_network_plugin()
         kube.join_master()
         kube.join_node()
         kube.install_helm()
         kube.install_istio()
-        kube.cp_kube_config()
         # 更新nginx服务tcp代理apiserever cluster
         nginx.renew_apiserver_config()
 
+
         # install service
         services = {
             "mage": MageController,
@@ -116,7 +125,8 @@ def deploy_main(args):
             "nlp": NlpController,
             "captcha": CaptchaController,
             "ocr_standard": OcrStandardController,
-            "ocr": OcrController
+            "ocr": OcrController,
+            "seal": SealController
         }
 
         middlewares = {
