@@ -140,9 +140,10 @@ class MysqlController(MiddlewareInterface):
             sql = SqlModule(host=Ipaddress, port=Port, user=self.user, passwd=self.password)
             sql.insert_sql("create table test.student (id int(10),name char(100),primary key (ID));")
             sql.insert_sql("insert into test.student (id,name)values(1,'Reading and writing tests');")
-            if sql.select("select * from test.student;"):
-                log.info("Mysql {IP}:{PORT} 读写测试成功...".format(IP=Ipaddress, PORT=Port))
-                sql.insert_sql("drop table test.student;")
+            sql.select("select * from test.student;")
+            sql.insert_sql("drop table test.student;")
+            log.info("Mysql {IP}:{PORT} 读写测试成功...".format(IP=Ipaddress, PORT=Port))
+
         except Exception as e:
             log.info("Mysql {IP}:{PORT} 读写测试失败...".format(IP=Ipaddress, PORT=Port))
             log.error(e)
@@ -173,7 +174,7 @@ class MysqlController(MiddlewareInterface):
             self.backup_sh_file,
             self.backup_conf_file,
             self.mysql_cfg["mysql"]["harbor_ipaddress"],
-            self.mysql_cfg["mysql"]["harbor_http_port"]
+            self.mysql_cfg["mysql"]["nginx_harbor_proxy_port"]
             )
         self.chmod_backupsh = "chmod +x {}".format(self.backup_sh_file)
 
