@@ -85,8 +85,10 @@ class MiddlewareConfigHandler(object):
             cfg = self.load()
             cfg[self.name]["lb"] = self.check_result.lb
             cfg[self.name]["deploy_type"] = "single" if len(self.check_result.config.servers) <= 1 else "cluster"
+            cfg[self.name]["nginx_harbor_proxy_port"] = get_port("harbor", "nginx_harbor_proxy_port")
             cfg[self.name]["harbor_http_port"] = get_port("harbor", "http_port")
-            cfg[self.name]["harbor_ipaddress"] = self.servers.get_role_obj("harbor")[0].ipaddress
+            cfg[self.name]["harbor_ipaddress"] = self.check_result.lb
+            cfg[self.name]["master_harbor_ipaddress"] = self.servers.get_role_obj("harbor")[0].ipaddress
             return cfg
         except UtilsError:
             return {}
@@ -120,8 +122,9 @@ class MinioConfigHandler(MiddlewareConfigHandler):
 class HarborConfigHandler(MiddlewareConfigHandler):
     def __init__(self):
         super(HarborConfigHandler, self).__init__("harbor")
-        self.permit_keys = ("http_port", "password")
+        self.permit_keys = ("http_port", "password", "nginx_harbor_proxy_port")
         self.cfg["http_port"] = get_port("harbor", "http_port")
+        self.cfg["nginx_harbor_proxy_port"] = get_port("harbor", "nginx_harbor_proxy_port")
         self.cfg["password"] = gen_pass()
 
 class RedisConfigHandler(MiddlewareConfigHandler):
