@@ -6,15 +6,16 @@ from laipvt.sysutil.gvalue import PORT_MAP
 
 module_require_tfserver = ("ocr_standard", "captcha", "nlp")
 tfserver_name = {
-    "ocr_standard": ["ocr-ctpn-tf-server", "ocr-text-recognition-tf-server"],
+    "ocr_standard": ["ocr-ctpn-tf-server", "ocr-text-recognition-tf-server",
+                     "ocr-unet-table-tf-serving", "semantic-correct"],
     "captcha": ["verification-tf-serving"],
     "nlp": ["bert-service-tf"]
 }
 
 tfserver_image_name = {
-    "ocr_standard": "tensorflow-serving",
-    "captcha": "tensorflow-serving",
-    "nlp": "tfserver"
+    "ocr_standard": "tfserving",
+    "captcha": "tfserving",
+    "nlp": "tfserving"
 }
 
 service_module_relation = {
@@ -76,17 +77,18 @@ middleware_port_relation = {
         "nginx_proxy_port": 10000
     },
     "harbor": {
-        "http_port": 8888
+        "http_port": 8888,
+        "nginx_harbor_proxy_port": 8889
     },
     "redis": {
         "port": 6379,
         "port_sentinel": 26379
     },
     "nginx": {
-        "commander_port": 80,
-        "commander_tenant_port": 81,
+        "commander_port": 8080,
+        "commander_tenant_port": 8081,
         "k8s_proxy_port": 6444,
-        "mage_proxy_port": 82
+        "mage_proxy_port": 8082
     },
     "mysql": {
         "port": 3306,
